@@ -17,7 +17,8 @@ key = {
   "ccd_x0": "/measurement/instrument/acquisition/beam_center_x",
   "ccd_y0": "/measurement/instrument/acquisition/beam_center_y",
   "det_dist": "/measurement/instrument/detector/distance",
-  "pix_dim": "/measurement/instrument/detector/x_pixel_size",
+  "pix_dim_x": "/measurement/instrument/detector/x_pixel_size",
+  "pix_dim_y": "/measurement/instrument/detector/y_pixel_size",
   "X_energy": "/measurement/instrument/source_begin/energy",
   "xdim": "/measurement/instrument/detector/x_dimension",
   "ydim": "/measurement/instrument/detector/y_dimension",
